==> aroundme_0_4_1.zip: aroundme_0_4_1/www/template/menu.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<table width="100%" border="0" cellspacing="0" cellpadding="4">
	<tr>
		<td class="txt_title">
			<?php echo $lang['section_menu'];?><br />
			<hr />
		</td>
	</tr>
	<tr>
       	<td valign="top" class='txt_sub_menu_on'>
			<?
			if ($pagename == "index") {
			    echo $lang['menu_home'] . "<br />";
			}
			else {
				echo "<a href='index.php' class='txt_sub_menu'>" . $lang['menu_home'] . "</a><br />";
			}
			if (isset($allow_registration) && $allow_registration == 1) {
				if ($pagename == "register") {
				    echo $lang['menu_register'] . "<br />";
				}
				else {
					echo "<a href='register.php' class='txt_sub_menu'>" . $lang['menu_register'] . "</a><br />";
				}
			}

			if ($pagename == "barnraiser") {
			    echo $lang['menu_barnraiser'] . "<br />";
			}
			else {
				echo "<a href='http://www.barnraiser.org/' class='txt_sub_menu'>" . $lang['menu_barnraiser'] . "</a><br />";
			}

			if ($pagename == "info") {
			    echo $lang['menu_info'] . "<br />";
			}
			else {
				echo "<a href='info.php' class='txt_sub_menu'>" . $lang['menu_info'] . "</a><br />";
			}
			?>
		</td>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

<table cellpadding="4" cellspacing="0" border="0" width="100%">
	<tr>
		<td class="txt_light" align="center">
			<?php echo $lang['menu_strap'];?><br />
		</td>
	</tr>
	<tr>
		<td>
			<a href="http://www.barnraiser.org/aroundme/" title="<?php echo $lang['title_home'];?>"><img src="<?php echo $templatePath;?>img/aroundme.png" width="160" height="161" alt="aroundme" border="0" /></a><br />
		</td>
	</tr>
</table>

==> aroundme_0_4_3.zip: aroundme_0_4_3/www/template/menu.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<table width="100%" border="0" cellspacing="0" cellpadding="4">
	<tr class="table_stnd">
		<td class="txt_title">
			<?php echo $lang['section_menu'];?><br />
			<hr />
		</td>
	</tr>
	<tr>
       	<td valign="top">
			<?
			if ($pagename == "index") {
			    echo "<span class=\"txt_sub_menu_on\">" . $lang['menu_home'] . "</span><br />";
			}
			else {
				echo "<a href='index.php' class='txt_sub_menu'>" . $lang['menu_home'] . "</a><br />";
			}
			if (isset($allow_registration) && $allow_registration == 1) {
				if ($pagename == "register") {
				    echo "<span class=\"txt_sub_menu_on\">" . $lang['menu_register'] . "</span><br />";
				}
				else {
					echo "<a href='register.php' class='txt_sub_menu'>" . $lang['menu_register'] . "</a><br />";
				}
			}

			if ($pagename == "barnraiser") {
			    echo "<span class=\"txt_sub_menu_on\">" . $lang['menu_barnraiser'] . "</span><br />";
			}
			else {
				echo "<a href='http://www.barnraiser.org/' class='txt_sub_menu'>" . $lang['menu_barnraiser'] . "</a><br />";
			}

			if ($pagename == "info") {
			    echo "<span class=\"txt_sub_menu_on\">" . $lang['menu_info'] . "</span><br />";
			}
			else {
				echo "<a href='info.php' class='txt_sub_menu'>" . $lang['menu_info'] . "</a><br />";
			}
			?>
		</td>
	</tr>
</table>

<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

<table cellpadding="4" cellspacing="0" border="0" width="100%">
	<tr>
		<td class="txt_light" align="center">
			<?php echo $lang['menu_strap'];?><br />
		</td>
	</tr>
	<tr>
		<td>
			<a href="http://www.barnraiser.org/aroundme/" title="<?php echo $lang['title_home'];?>"><img src="<?php echo $templatePath;?>img/aroundme.png" width="160" height="161" alt="aroundme" border="0" /></a><br />
		</td>
	</tr>
</table>
